@@ -249,21 +249,24 @@ def main(argv=None):
     jugspace = None
     store = None
 
+
     try:
         if options.subcommand not in ('demo', 'status', 'execute', 'webstatus', 'test-jug'):
             on_error = ('propagate' if options.pdb else 'exit')
             store, jugspace = init(options.jugfile, options.jugdir, on_error=on_error)
         from .subcommands import cmdapi
-        cmdapi.run(options.subcommand, options=options, store=store, jugspace=jugspace)
+        retval = cmdapi.run(options.subcommand, options=options, store=store, jugspace=jugspace)
     except:
         if options.pdb:
             from .internal.debugger import debug_exception
             debug_exception()
+            retval = 1
         else:
             raise
     finally:
         if store is not None:
             store.close()
+    sys.exit(retval)
 
 
 if __name__ == '__main__':
