@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2008-2017, Luis Pedro Coelho <luis@luispedro.org>
+# Copyright (C) 2008-2020, Luis Pedro Coelho <luis@luispedro.org>
 # vim: set ts=4 sts=4 sw=4 expandtab smartindent:
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -40,7 +40,7 @@ import six
 import sys
 
 
-class Options(object):
+class Options:
     def __init__(self, next, autoinit=False):
         self.next = next
         self._autoinit = autoinit
@@ -135,7 +135,7 @@ def read_configuration_file(fp=None, default_options=None):
 
     from six.moves import configparser
     config = configparser.RawConfigParser()
-    config.readfp(fp)
+    config.read_file(fp)
     fp.close()
 
     for section in config.sections():
