@@ -28,7 +28,9 @@ from . import SubCommand
 template = '''
 <html>
 <head>
-
+<head>
+  <meta http-equiv="refresh" content="%(refresh)s">
+</head>
 <title>Jug Status :: %(jugfile)s</title>
 <style>
 body {
@@ -107,6 +109,7 @@ class WebStatusCommand(SubCommand):
 
         try:
             import bottle
+            from bottle import request
         except ImportError:
             from sys import stderr
             stderr.write('''
@@ -122,17 +125,39 @@ class WebStatusCommand(SubCommand):
             return
 
         app = bottle.Bottle()
-
         @app.route('/')
         def status():
             ht, deps, rdeps = st.retrieve_sqlite3(connection)
-            tw, tre, tru, tf, dirty = st.update_status(store, ht, deps, rdeps)
+            tw, tre, tru, tfailed, tf, dirty = st.update_status(store, ht, deps, rdeps)
             st.save_dirty3(connection, dirty)
             return template % {
                 'jugfile': options.jugfile,
+                'refresh': request.query.refresh or "3",
                 'table': _format_counts(tw, tre, tru, tf),
             }
-        bottle.run(app)
+        bottle.run(app, port=options.webstatus_port,
+                   host=options.webstatus_ip, quiet=True)
+
+    def parse(self, parser):
+        defaults = self.parse_defaults()
+        parser.add_argument('--port',
+                            action='store', 
+                            dest='webstatus_port',
+                            help=('Port for the webstatus serve to listen on'
+                                  ' (Default: 8080)')
+        )
+        parser.add_argument('--ip',
+                            action='store',
+                            dest='webstatus_ip',
+                            help=('The IP address the webstatus server will listen on.'
+                                  ' (Default: localhost)')
+        )
+
+    def parse_defaults(self):
+        return {
+            "webstatus_port": '8080',
+            "webstatus_ip": 'localhost'
+        }
 
 
 webstatus = WebStatusCommand()
